@@ -24,13 +24,13 @@ AWSTATS_ENABLE_BUILDSTATICPAGES="yes"
 AWSTATS_LANG="en"
 [ ! -r "$DEFAULT" ] || . "$DEFAULT"
 
-[ "$AWSTATS_ENABLE_BUILDSTATICPAGES" == "yes" ] || exit 0
+[ "$AWSTATS_ENABLE_BUILDSTATICPAGES" = "yes" ] || exit 0
 
 cd /etc/awstats
 
-for c in awstats \
-         `/bin/ls -1 awstats.*.conf 2>/dev/null | \
-          /bin/sed 's/^awstats\.\(.*\)\.conf/\1/'`
+for c in `/bin/ls -1 awstats.*.conf 2>/dev/null | \
+          /bin/sed 's/^awstats\.\(.*\)\.conf/\1/'` \
+         `[ -f /etc/awstats/awstats.conf ] && echo awstats`
 do
   mkdir -p /var/cache/awstats/$c/$YEAR/$MONTH/
 
