@@ -22,7 +22,8 @@ AWSTATS_NICE=10
 cd /etc/awstats
 
 for c in `/bin/ls -1 awstats.*.conf 2>/dev/null | \
-          /bin/sed 's/^awstats\.\(.*\)\.conf/\1/'` awstats
+          /bin/sed 's/^awstats\.\(.*\)\.conf/\1/'` \
+         `[ -f /etc/awstats/awstats.conf ] && echo awstats`
 do
   if ! nice -n $AWSTATS_NICE $AWSTATS \
 	  -config=$c \
